# Generated by Django 3.0.6 on 2020-05-14 23:31

import uuid

import _socket
import django.core.validators
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_model.models.fields.other_charfield
import edc_model.validators.date
import edc_protocol.validators
import edc_sites.models
import edc_utils.date
import simple_history.models
from django.conf import settings
from django.db import migrations, models

import sarscov2.models.coronavirus_kap

try:
    import edc_model.models.fields.blood_pressure
    import edc_vitals.models.fields.height
    import edc_vitals.models.fields.weight
except (ModuleNotFoundError, AttributeError):
    import edc_vitals.models.fields.blood_pressure
    import edc_vitals.models.fields.height
    import edc_vitals.models.fields.weight


class Migration(migrations.Migration):

    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("sarscov2", "0002_auto_20200416_1937"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="coronakapinformationsources",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "ordering": ["display_index", "display_name"],
                "verbose_name": "KAP Information Sources",
                "verbose_name_plural": "KAP Information Sources",
            },
        ),
        migrations.CreateModel(
            name="HistoricalCoronavirusKap",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default="COMPLETE",
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "hiv_pos",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                        max_length=25,
                        verbose_name="Does the patient have <u>HIV</u> infection?",
                    ),
                ),
                (
                    "hiv_pos_year",
                    models.IntegerField(
                        blank=True,
                        help_text="format YYYY",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(1950),
                            django.core.validators.MaxValueValidator(2020),
                        ],
                        verbose_name="If 'Yes', what year did you first test positive?",
                    ),
                ),
                (
                    "hiv_year_started_art",
                    models.IntegerField(
                        blank=True,
                        help_text="format YYYY",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If 'Yes', what year did you <u>start antiretroviral therapy</u>?",
                    ),
                ),
                (
                    "hiv_missed_doses",
                    models.IntegerField(
                        blank=True,
                        null=True,
                        verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>ART</u> medications?",
                    ),
                ),
                (
                    "diabetic",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                        max_length=25,
                        verbose_name="Have you been diagnosed with <u>diabetes</u>?",
                    ),
                ),
                (
                    "diabetic_dx_year",
                    models.IntegerField(
                        blank=True,
                        help_text="format YYYY",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(1950),
                            django.core.validators.MaxValueValidator(2020),
                        ],
                        verbose_name="If 'Yes', what year did you first learn you had <u>diabetes</u>?",
                    ),
                ),
                (
                    "diabetic_on_meds",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        verbose_name="If 'Yes', are you taking medications to control your <u>diabetes</u>?",
                    ),
                ),
                (
                    "diabetic_missed_doses",
                    models.IntegerField(
                        blank=True,
                        null=True,
                        verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>diabetes</u> medications?",
                    ),
                ),
                (
                    "hypertensive",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                        max_length=25,
                        verbose_name="Have you been diagnosed with <u>hypertension</u>?",
                    ),
                ),
                (
                    "hypertensive_dx_year",
                    models.IntegerField(
                        blank=True,
                        help_text="format YYYY",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(1950),
                            django.core.validators.MaxValueValidator(2020),
                        ],
                        verbose_name="If 'Yes', what year did you first learn you had <u>hypertension</u>?",
                    ),
                ),
                (
                    "hypertensive_on_meds",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        verbose_name="If 'Yes', are you taking medications to control your <u>hypertension</u>?",
                    ),
                ),
                (
                    "hypertensive_missed_doses",
                    models.IntegerField(
                        blank=True,
                        null=True,
                        verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>hypertension</u> medications?",
                    ),
                ),
                (
                    "weight",
                    edc_vitals.models.fields.weight.WeightField(blank=True, null=True),
                ),
                (
                    "height",
                    edc_vitals.models.fields.height.HeightField(blank=True, null=True),
                ),
                (
                    "sys_blood_pressure",
                    edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                        blank=True, null=True
                    ),
                ),
                (
                    "dia_blood_pressure",
                    edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                        blank=True, null=True
                    ),
                ),
                (
                    "married",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="Are you currently married?",
                    ),
                ),
                (
                    "employment_status",
                    models.CharField(
                        choices=[
                            ("working_for_pay", "Working for pay / Employed"),
                            ("not_working_for_pay", "Not working for pay / Unemployed"),
                        ],
                        max_length=25,
                        verbose_name="Are you employed / working?",
                    ),
                ),
                (
                    "employment",
                    models.CharField(
                        choices=[
                            ("professional", "Professional (e.g. office"),
                            ("labourer", "Labourer"),
                            ("self_employed", "Small business, self-employed"),
                            ("N/A", "Not applicable"),
                            ("OTHER", "Other, specify below"),
                        ],
                        default="N/A",
                        max_length=25,
                        verbose_name="What type of <u>paid</u> work / employment are you involved in?",
                    ),
                ),
                (
                    "employment_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "unpaid_work",
                    models.CharField(
                        choices=[
                            ("volunteer", "Volunteer"),
                            ("unpaid_intern", "Unpaid Intern"),
                            ("housewife", "Housewife"),
                            ("retired", "Retired"),
                            ("N/A", "Not applicable"),
                            ("OTHER", "Other, specify below"),
                        ],
                        default="N/A",
                        max_length=25,
                        verbose_name="What type of <u>unpaid</u> work are you involved in?",
                    ),
                ),
                (
                    "unpaid_work_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "household_size",
                    models.IntegerField(
                        help_text="Family / people who spend more than 14 nights per month in your home.",
                        verbose_name="How many people live together in your home / dwelling?",
                    ),
                ),
                (
                    "nights_away",
                    models.IntegerField(
                        help_text="e.g. travelling for work, staying with family",
                        verbose_name="In the last one month, how many nights did you spend away from your home / dwelling?",
                    ),
                ),
                (
                    "education",
                    models.CharField(
                        choices=[
                            ("primary", "Up to primary"),
                            ("secondary", "Up to secondary"),
                            ("tertiary", "Tertiary (University, college)"),
                            ("no_education", "No education"),
                        ],
                        max_length=25,
                        verbose_name="What is your highest completed education level?",
                    ),
                ),
                (
                    "health_insurance",
                    models.CharField(
                        choices=[
                            ("work_scheme", "Work scheme health insurance"),
                            ("private", "Private health insurance"),
                            ("no_insurance", "No insurance, I pay"),
                            ("OTHER", "Other, please specify below"),
                        ],
                        max_length=25,
                        verbose_name="How are you covered for your health care expenses?",
                    ),
                ),
                (
                    "health_insurance_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "personal_health_opinion",
                    models.CharField(
                        choices=[
                            ("excellent", "Excellent"),
                            ("good", "Good"),
                            ("fair", "Fair"),
                            ("poor", "Poor"),
                        ],
                        max_length=25,
                        verbose_name="In your opinion, what is your health like?",
                    ),
                ),
                (
                    "perceived_threat",
                    models.IntegerField(
                        help_text="On a scale from 1-10",
                        validators=[
                            django.core.validators.MinValueValidator(1),
                            django.core.validators.MaxValueValidator(10),
                        ],
                        verbose_name="On a scale from 1-10, how serious of a public health threat is coronavirus?",
                    ),
                ),
                (
                    "corona_concern",
                    models.CharField(
                        choices=[
                            ("very", "Very worried"),
                            ("somewhat", "Somewhat worried"),
                            ("a_little", "A little worried"),
                            ("not_at_all", "Not worried at all"),
                        ],
                        max_length=25,
                        verbose_name="How worried are you about getting coronavirus?",
                    ),
                ),
                (
                    "personal_infection_likelihood",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="How likely do you think it is that <u>you</u> will get sick from coronavirus?",
                    ),
                ),
                (
                    "family_infection_likelihood",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="How likely do you think it is that <u>someone in your family</u> will get sick from coronavirus?",
                    ),
                ),
                (
                    "perc_die",
                    models.IntegerField(
                        help_text="On a scale from 0-100",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(100),
                        ],
                        verbose_name="Out of every 100 people who get infected with coronavirus, how many do you think <u>will die</u>?",
                    ),
                ),
                (
                    "perc_mild_symptom",
                    models.IntegerField(
                        help_text="On a scale from 0-100",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(100),
                        ],
                        verbose_name="Out of every 100 people who get infected with coronavirus, how many do you think <u>will have only mild symptoms</u>?",
                    ),
                ),
                (
                    "spread_droplets",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Coronavirus spreads by droplets from cough and sneezes from people infected with coronavirus",
                    ),
                ),
                (
                    "spread_touch",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Coronavirus can spread by people touching each other",
                    ),
                ),
                (
                    "spread_sick",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="People can transmit coronavirus when they are sick ",
                    ),
                ),
                (
                    "spread_asymptomatic",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="People can transmit coronavirus even when they do not appear to be sick",
                    ),
                ),
                (
                    "severity_age",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Coronavirus is more severe in older people than children",
                    ),
                ),
                (
                    "severity_hiv",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Coronavirus is more severe in people with <u>HIV infection</u>",
                    ),
                ),
                (
                    "severity_diabetes_hypertension",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Coronavirus is more severe in people with <u>diabetes</u> and/or <u>hypertension</u>",
                    ),
                ),
                (
                    "hot_climate",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Coronavirus does not survive in the hot climate",
                    ),
                ),
                (
                    "lives_on_materials",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Coronavirus can live on clothes, plastics, cardboard for a day or more",
                    ),
                ),
                (
                    "spread_touch2",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="You can catch coronavirus if you touch an infected area and then touch your face or eyes",
                    ),
                ),
                (
                    "symptoms_fever",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Fever",
                    ),
                ),
                (
                    "symptoms_headache",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Headache",
                    ),
                ),
                (
                    "symptoms_dry_cough",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Dry persistant cough",
                    ),
                ),
                (
                    "symptoms_body_aches",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Body aches",
                    ),
                ),
                (
                    "symptoms_smell",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Loss of taste and smell",
                    ),
                ),
                (
                    "symptoms_breathing",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Fast or difficult breathing",
                    ),
                ),
                (
                    "know_other_symptoms",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="Do you know of any other symptoms of coronavirus?",
                    ),
                ),
                (
                    "symptoms_other",
                    models.TextField(
                        blank=True,
                        max_length=250,
                        null=True,
                        verbose_name="Please list any other symptoms of coronavirus that you are aware of:",
                    ),
                ),
                (
                    "hot_drinks",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Drink warm water or hot drinks like tea or coffee",
                    ),
                ),
                (
                    "alcohol",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Drink alcohol, spirits, etc",
                    ),
                ),
                (
                    "wash_hands",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Wash hands with soap and warm water",
                    ),
                ),
                (
                    "hand_sanitizer",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Use hand sanitisers with alcohol",
                    ),
                ),
                (
                    "take_herbs_prevention",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Taking herbs",
                    ),
                ),
                (
                    "avoid_crowds",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Avoid crowded places such as markets and public transport",
                    ),
                ),
                (
                    "face_masks",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Wear a face mask",
                    ),
                ),
                (
                    "stay_indoors",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Stay indoors",
                    ),
                ),
                (
                    "social_distance",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Keep at least a 2 metre distance from people",
                    ),
                ),
                (
                    "other_actions_prevention",
                    models.TextField(
                        blank=True,
                        max_length=250,
                        null=True,
                        verbose_name="Any <u>other</u> things you would do to <u>protect</u> yourself from Coronavirus?",
                    ),
                ),
                (
                    "stay_home",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Stay at home and avoid people",
                    ),
                ),
                (
                    "visit_clinic",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Go to the nearest health facility",
                    ),
                ),
                (
                    "call_nurse",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Call your nurse and tell them you are sick",
                    ),
                ),
                (
                    "take_meds",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Take medicines like chloroquine",
                    ),
                ),
                (
                    "take_herbs_symptoms",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Take herbs",
                    ),
                ),
                (
                    "stop_chronic_meds",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        help_text="For example, medicines for diabetes, hypertension and/or HIV",
                        max_length=25,
                        verbose_name="Stop taking your chronic disease medicines",
                    ),
                ),
                (
                    "visit_religious",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Go to a religious leader instead of a doctor",
                    ),
                ),
                (
                    "visit_traditional",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Go to a traditional healer instead of a doctor",
                    ),
                ),
                (
                    "other_actions_symptoms",
                    models.TextField(
                        blank=True,
                        max_length=250,
                        null=True,
                        verbose_name="Any <u>other</u> things you would do if you had <u>symptoms</u> of Coronavirus?",
                    ),
                ),
                (
                    "subject_identifier",
                    models.CharField(
                        db_index=True,
                        max_length=50,
                        null=True,
                        verbose_name="Subject identifier",
                    ),
                ),
                (
                    "screening_identifier",
                    models.CharField(
                        db_index=True,
                        max_length=50,
                        null=True,
                        verbose_name="Screening identifier",
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                ("protocol", models.CharField(default="meta_edc", max_length=50)),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("history_date", models.DateTimeField()),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.Site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Coronavirus KAP",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": "history_date",
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="CoronavirusKap",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default="COMPLETE",
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "hiv_pos",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                        max_length=25,
                        verbose_name="Does the patient have <u>HIV</u> infection?",
                    ),
                ),
                (
                    "hiv_pos_year",
                    models.IntegerField(
                        blank=True,
                        help_text="format YYYY",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(1950),
                            django.core.validators.MaxValueValidator(2020),
                        ],
                        verbose_name="If 'Yes', what year did you first test positive?",
                    ),
                ),
                (
                    "hiv_year_started_art",
                    models.IntegerField(
                        blank=True,
                        help_text="format YYYY",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If 'Yes', what year did you <u>start antiretroviral therapy</u>?",
                    ),
                ),
                (
                    "hiv_missed_doses",
                    models.IntegerField(
                        blank=True,
                        null=True,
                        verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>ART</u> medications?",
                    ),
                ),
                (
                    "diabetic",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                        max_length=25,
                        verbose_name="Have you been diagnosed with <u>diabetes</u>?",
                    ),
                ),
                (
                    "diabetic_dx_year",
                    models.IntegerField(
                        blank=True,
                        help_text="format YYYY",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(1950),
                            django.core.validators.MaxValueValidator(2020),
                        ],
                        verbose_name="If 'Yes', what year did you first learn you had <u>diabetes</u>?",
                    ),
                ),
                (
                    "diabetic_on_meds",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        verbose_name="If 'Yes', are you taking medications to control your <u>diabetes</u>?",
                    ),
                ),
                (
                    "diabetic_missed_doses",
                    models.IntegerField(
                        blank=True,
                        null=True,
                        verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>diabetes</u> medications?",
                    ),
                ),
                (
                    "hypertensive",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                        max_length=25,
                        verbose_name="Have you been diagnosed with <u>hypertension</u>?",
                    ),
                ),
                (
                    "hypertensive_dx_year",
                    models.IntegerField(
                        blank=True,
                        help_text="format YYYY",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(1950),
                            django.core.validators.MaxValueValidator(2020),
                        ],
                        verbose_name="If 'Yes', what year did you first learn you had <u>hypertension</u>?",
                    ),
                ),
                (
                    "hypertensive_on_meds",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        verbose_name="If 'Yes', are you taking medications to control your <u>hypertension</u>?",
                    ),
                ),
                (
                    "hypertensive_missed_doses",
                    models.IntegerField(
                        blank=True,
                        null=True,
                        verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>hypertension</u> medications?",
                    ),
                ),
                (
                    "weight",
                    edc_vitals.models.fields.weight.WeightField(blank=True, null=True),
                ),
                (
                    "height",
                    edc_vitals.models.fields.height.HeightField(blank=True, null=True),
                ),
                (
                    "sys_blood_pressure",
                    edc_vitals.models.fields.blood_pressure.SystolicPressureField(
                        blank=True, null=True
                    ),
                ),
                (
                    "dia_blood_pressure",
                    edc_vitals.models.fields.blood_pressure.DiastolicPressureField(
                        blank=True, null=True
                    ),
                ),
                (
                    "married",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="Are you currently married?",
                    ),
                ),
                (
                    "employment_status",
                    models.CharField(
                        choices=[
                            ("working_for_pay", "Working for pay / Employed"),
                            ("not_working_for_pay", "Not working for pay / Unemployed"),
                        ],
                        max_length=25,
                        verbose_name="Are you employed / working?",
                    ),
                ),
                (
                    "employment",
                    models.CharField(
                        choices=[
                            ("professional", "Professional (e.g. office"),
                            ("labourer", "Labourer"),
                            ("self_employed", "Small business, self-employed"),
                            ("N/A", "Not applicable"),
                            ("OTHER", "Other, specify below"),
                        ],
                        default="N/A",
                        max_length=25,
                        verbose_name="What type of <u>paid</u> work / employment are you involved in?",
                    ),
                ),
                (
                    "employment_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "unpaid_work",
                    models.CharField(
                        choices=[
                            ("volunteer", "Volunteer"),
                            ("unpaid_intern", "Unpaid Intern"),
                            ("housewife", "Housewife"),
                            ("retired", "Retired"),
                            ("N/A", "Not applicable"),
                            ("OTHER", "Other, specify below"),
                        ],
                        default="N/A",
                        max_length=25,
                        verbose_name="What type of <u>unpaid</u> work are you involved in?",
                    ),
                ),
                (
                    "unpaid_work_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "household_size",
                    models.IntegerField(
                        help_text="Family / people who spend more than 14 nights per month in your home.",
                        verbose_name="How many people live together in your home / dwelling?",
                    ),
                ),
                (
                    "nights_away",
                    models.IntegerField(
                        help_text="e.g. travelling for work, staying with family",
                        verbose_name="In the last one month, how many nights did you spend away from your home / dwelling?",
                    ),
                ),
                (
                    "education",
                    models.CharField(
                        choices=[
                            ("primary", "Up to primary"),
                            ("secondary", "Up to secondary"),
                            ("tertiary", "Tertiary (University, college)"),
                            ("no_education", "No education"),
                        ],
                        max_length=25,
                        verbose_name="What is your highest completed education level?",
                    ),
                ),
                (
                    "health_insurance",
                    models.CharField(
                        choices=[
                            ("work_scheme", "Work scheme health insurance"),
                            ("private", "Private health insurance"),
                            ("no_insurance", "No insurance, I pay"),
                            ("OTHER", "Other, please specify below"),
                        ],
                        max_length=25,
                        verbose_name="How are you covered for your health care expenses?",
                    ),
                ),
                (
                    "health_insurance_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "personal_health_opinion",
                    models.CharField(
                        choices=[
                            ("excellent", "Excellent"),
                            ("good", "Good"),
                            ("fair", "Fair"),
                            ("poor", "Poor"),
                        ],
                        max_length=25,
                        verbose_name="In your opinion, what is your health like?",
                    ),
                ),
                (
                    "perceived_threat",
                    models.IntegerField(
                        help_text="On a scale from 1-10",
                        validators=[
                            django.core.validators.MinValueValidator(1),
                            django.core.validators.MaxValueValidator(10),
                        ],
                        verbose_name="On a scale from 1-10, how serious of a public health threat is coronavirus?",
                    ),
                ),
                (
                    "corona_concern",
                    models.CharField(
                        choices=[
                            ("very", "Very worried"),
                            ("somewhat", "Somewhat worried"),
                            ("a_little", "A little worried"),
                            ("not_at_all", "Not worried at all"),
                        ],
                        max_length=25,
                        verbose_name="How worried are you about getting coronavirus?",
                    ),
                ),
                (
                    "personal_infection_likelihood",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="How likely do you think it is that <u>you</u> will get sick from coronavirus?",
                    ),
                ),
                (
                    "family_infection_likelihood",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="How likely do you think it is that <u>someone in your family</u> will get sick from coronavirus?",
                    ),
                ),
                (
                    "perc_die",
                    models.IntegerField(
                        help_text="On a scale from 0-100",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(100),
                        ],
                        verbose_name="Out of every 100 people who get infected with coronavirus, how many do you think <u>will die</u>?",
                    ),
                ),
                (
                    "perc_mild_symptom",
                    models.IntegerField(
                        help_text="On a scale from 0-100",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(100),
                        ],
                        verbose_name="Out of every 100 people who get infected with coronavirus, how many do you think <u>will have only mild symptoms</u>?",
                    ),
                ),
                (
                    "spread_droplets",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Coronavirus spreads by droplets from cough and sneezes from people infected with coronavirus",
                    ),
                ),
                (
                    "spread_touch",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Coronavirus can spread by people touching each other",
                    ),
                ),
                (
                    "spread_sick",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="People can transmit coronavirus when they are sick ",
                    ),
                ),
                (
                    "spread_asymptomatic",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="People can transmit coronavirus even when they do not appear to be sick",
                    ),
                ),
                (
                    "severity_age",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Coronavirus is more severe in older people than children",
                    ),
                ),
                (
                    "severity_hiv",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Coronavirus is more severe in people with <u>HIV infection</u>",
                    ),
                ),
                (
                    "severity_diabetes_hypertension",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Coronavirus is more severe in people with <u>diabetes</u> and/or <u>hypertension</u>",
                    ),
                ),
                (
                    "hot_climate",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Coronavirus does not survive in the hot climate",
                    ),
                ),
                (
                    "lives_on_materials",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Coronavirus can live on clothes, plastics, cardboard for a day or more",
                    ),
                ),
                (
                    "spread_touch2",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="You can catch coronavirus if you touch an infected area and then touch your face or eyes",
                    ),
                ),
                (
                    "symptoms_fever",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Fever",
                    ),
                ),
                (
                    "symptoms_headache",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Headache",
                    ),
                ),
                (
                    "symptoms_dry_cough",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Dry persistant cough",
                    ),
                ),
                (
                    "symptoms_body_aches",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Body aches",
                    ),
                ),
                (
                    "symptoms_smell",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Loss of taste and smell",
                    ),
                ),
                (
                    "symptoms_breathing",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Fast or difficult breathing",
                    ),
                ),
                (
                    "know_other_symptoms",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="Do you know of any other symptoms of coronavirus?",
                    ),
                ),
                (
                    "symptoms_other",
                    models.TextField(
                        blank=True,
                        max_length=250,
                        null=True,
                        verbose_name="Please list any other symptoms of coronavirus that you are aware of:",
                    ),
                ),
                (
                    "hot_drinks",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Drink warm water or hot drinks like tea or coffee",
                    ),
                ),
                (
                    "alcohol",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Drink alcohol, spirits, etc",
                    ),
                ),
                (
                    "wash_hands",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Wash hands with soap and warm water",
                    ),
                ),
                (
                    "hand_sanitizer",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Use hand sanitisers with alcohol",
                    ),
                ),
                (
                    "take_herbs_prevention",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Taking herbs",
                    ),
                ),
                (
                    "avoid_crowds",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Avoid crowded places such as markets and public transport",
                    ),
                ),
                (
                    "face_masks",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Wear a face mask",
                    ),
                ),
                (
                    "stay_indoors",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Stay indoors",
                    ),
                ),
                (
                    "social_distance",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Keep at least a 2 metre distance from people",
                    ),
                ),
                (
                    "other_actions_prevention",
                    models.TextField(
                        blank=True,
                        max_length=250,
                        null=True,
                        verbose_name="Any <u>other</u> things you would do to <u>protect</u> yourself from Coronavirus?",
                    ),
                ),
                (
                    "stay_home",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Stay at home and avoid people",
                    ),
                ),
                (
                    "visit_clinic",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Go to the nearest health facility",
                    ),
                ),
                (
                    "call_nurse",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Call your nurse and tell them you are sick",
                    ),
                ),
                (
                    "take_meds",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Take medicines like chloroquine",
                    ),
                ),
                (
                    "take_herbs_symptoms",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Take herbs",
                    ),
                ),
                (
                    "stop_chronic_meds",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        help_text="For example, medicines for diabetes, hypertension and/or HIV",
                        max_length=25,
                        verbose_name="Stop taking your chronic disease medicines",
                    ),
                ),
                (
                    "visit_religious",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Go to a religious leader instead of a doctor",
                    ),
                ),
                (
                    "visit_traditional",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Go to a traditional healer instead of a doctor",
                    ),
                ),
                (
                    "other_actions_symptoms",
                    models.TextField(
                        blank=True,
                        max_length=250,
                        null=True,
                        verbose_name="Any <u>other</u> things you would do if you had <u>symptoms</u> of Coronavirus?",
                    ),
                ),
                (
                    "subject_identifier",
                    models.CharField(
                        max_length=50,
                        null=True,
                        unique=True,
                        verbose_name="Subject identifier",
                    ),
                ),
                (
                    "screening_identifier",
                    models.CharField(
                        max_length=50,
                        null=True,
                        unique=True,
                        verbose_name="Screening identifier",
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                ("protocol", models.CharField(default="meta_edc", max_length=50)),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.Site",
                    ),
                ),
            ],
            options={
                "verbose_name": "Coronavirus KAP",
                "verbose_name_plural": "Coronavirus KAP",
            },
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", sarscov2.models.coronavirus_kap.CoronaKapManager()),
            ],
        ),
    ]
